@@ -19,7 +19,7 @@
 #pragma warning(push, 0)
 #endif
 #include <google/protobuf/text_format.h>
-#include <ignition/msgs/fuel_metadata.pb.h>
+#include <gz/msgs/fuel_metadata.pb.h>
 #ifdef _MSC_VER
 #pragma warning(pop)
 #endif
@@ -32,32 +32,33 @@
 #include <regex>
 #include <string>
 
-#include <ignition/common/Console.hh>
-#include <ignition/common/Filesystem.hh>
-#include <ignition/common/Util.hh>
+#include <gz/common/Console.hh>
+#include <gz/common/Filesystem.hh>
+#include <gz/common/URI.hh>
+#include <gz/common/Util.hh>
 
-#include <ignition/msgs/Utility.hh>
+#include <gz/msgs/Utility.hh>
 
-#include "ignition/fuel_tools/ClientConfig.hh"
-#include "ignition/fuel_tools/CollectionIdentifier.hh"
-#include "ignition/fuel_tools/FuelClient.hh"
+#include "gz/fuel_tools/ClientConfig.hh"
+#include "gz/fuel_tools/CollectionIdentifier.hh"
+#include "gz/fuel_tools/FuelClient.hh"
 #include "ignition/fuel_tools/Helpers.hh"
-#include "ignition/fuel_tools/JSONParser.hh"
-#include "ignition/fuel_tools/LocalCache.hh"
-#include "ignition/fuel_tools/ModelIdentifier.hh"
+#include "gz/fuel_tools/JSONParser.hh"
+#include "gz/fuel_tools/LocalCache.hh"
+#include "gz/fuel_tools/ModelIdentifier.hh"
 #include "ModelIterPrivate.hh"
-#include "ignition/fuel_tools/RestClient.hh"
-#include "ignition/fuel_tools/WorldIdentifier.hh"
+#include "gz/fuel_tools/RestClient.hh"
+#include "gz/fuel_tools/WorldIdentifier.hh"
 #include "WorldIterPrivate.hh"
 
 using namespace ignition;
 using namespace fuel_tools;
 
 /// \brief Private Implementation
-class ignition::fuel_tools::FuelClientPrivate
+class gz::fuel_tools::FuelClientPrivate
 {
   /// \brief A model URL,
-  /// E.g.: https://fuel.ignitionrobotics.org/1.0/caguero/models/Beer/2
+  /// E.g.: https://fuel.gazebosim.org/1.0/caguero/models/Beer/2
   /// Where the API version and the model version are optional.
   public: const std::string kModelUrlRegexStr{
     // Method
@@ -78,7 +79,7 @@ class ignition::fuel_tools::FuelClientPrivate
     "/?"};
 
   /// \brief A world URL,
-  /// E.g.: https://fuel.ignitionrobotics.org/1.0/OpenRobotics/worlds/Empty/1
+  /// E.g.: https://fuel.gazebosim.org/1.0/OpenRobotics/worlds/Empty/1
   /// Where the API version and the world version are optional.
   public: const std::string kWorldUrlRegexStr{
     // Method
@@ -150,7 +151,7 @@ class ignition::fuel_tools::FuelClientPrivate
 
   /// \brief A collection URL,
   /// E.g.:
-  /// https://fuel.ignitionrobotics.org/1.0/OpenRobotics/collections/TestColl
+  /// https://fuel.gazebosim.org/1.0/OpenRobotics/collections/TestColl
   /// Where the API version is optional
   public: const std::string kCollectionUrlRegexStr{
     // Method
@@ -197,6 +198,17 @@ class ignition::fuel_tools::FuelClientPrivate
   /// license information.
   public: void PopulateLicenses(const ServerConfig &_server);
 
+  /// \brief Checks the provided URI for fuel.gazebosim.org, and
+  /// prints a deprecation warning message if found.
+  /// \param[in] _uri URI to check
+  /// DEPRECATED/DEPRECATION: remove this function in Gazebo H.
+  public: void CheckForDeprecatedUri(const common::URI &_uri);
+
+  /// \brief Get zip data from a REST response. This is used by world and
+  /// model download.
+  public: void ZipFromResponse(const RestResponse &_resp,
+              std::string &_zip);
+
   /// \brief Client configuration
   public: ClientConfig config;
 
@@ -405,16 +417,31 @@ WorldIter FuelClient::Worlds(const ServerConfig &_server) const
 //////////////////////////////////////////////////
 ModelIter FuelClient::Models(const ModelIdentifier &_id)
 {
-  return const_cast<const FuelClient*>(this)->Models(_id);
+  return this->Models(_id, true);
 }
 
 //////////////////////////////////////////////////
 ModelIter FuelClient::Models(const ModelIdentifier &_id) const
 {
-  // Check local cache first
-  ModelIter localIter = this->dataPtr->cache->MatchingModels(_id);
-  if (localIter)
-    return localIter;
+  return this->Models(_id, true);
+}
+
+//////////////////////////////////////////////////
+ModelIter FuelClient::Models(const ModelIdentifier &_id, bool _checkCache)
+{
+  return const_cast<const FuelClient*>(this)->Models(_id, _checkCache);
+}
+
+//////////////////////////////////////////////////
+ModelIter FuelClient::Models(const ModelIdentifier &_id, bool _checkCache) const
+{
+  if (_checkCache)
+  {
+    // Check local cache first
+    ModelIter localIter = this->dataPtr->cache->MatchingModels(_id);
+    if (localIter)
+      return localIter;
+  }
 
   // TODO(nkoenig) try to fetch model directly from a server
   // Note: ign-fuel-server doesn't like URLs ending in /
@@ -425,7 +452,7 @@ ModelIter FuelClient::Models(const ModelIdentifier &_id) const
     path = path / _id.Owner() / "models";
 
   if (path.Str().empty())
-    return localIter;
+    return ModelIterFactory::Create();
 
   ignmsg << _id.UniqueName() << " not found in cache, attempting download\n";
 
@@ -560,9 +587,11 @@ void FuelClient::AddServerConfigParametersToHeaders(
 }
 
 //////////////////////////////////////////////////
-Result FuelClient::DeleteUrl(const ignition::common::URI &_uri,
+Result FuelClient::DeleteUrl(const gz::common::URI &_uri,
     const std::vector<std::string> &_headers)
 {
+  this->dataPtr->CheckForDeprecatedUri(_uri);
+
   Rest rest;
   RestResponse resp;
 
@@ -665,6 +694,7 @@ Result FuelClient::DownloadModel(const ModelIdentifier &_id,
           << std::endl << _id.Server().AsString() << std::endl;
     return Result(ResultType::FETCH_ERROR);
   }
+  this->dataPtr->CheckForDeprecatedUri(_id.Server().Url());
 
   // Route
   common::URIPath route;
@@ -680,7 +710,7 @@ Result FuelClient::DownloadModel(const ModelIdentifier &_id,
   Rest rest;
   RestResponse resp;
   resp = rest.Request(HttpMethod::GET, _id.Server().Url().Str(),
-      _id.Server().Version(), route.Str(), {},
+      _id.Server().Version(), route.Str(), {"link=true"},
       headersIncludingServerConfig, "");
   if (resp.statusCode != 200)
   {
@@ -714,9 +744,12 @@ Result FuelClient::DownloadModel(const ModelIdentifier &_id,
   }
   newId.SetVersion(version);
 
+  std::string zipData;
+  this->dataPtr->ZipFromResponse(resp, zipData);
+
   // Save
   // Note that the save function doesn't return the path
-  if (!this->dataPtr->cache->SaveModel(newId, resp.data, true))
+  if (zipData.empty() || !this->dataPtr->cache->SaveModel(newId, zipData, true))
     return Result(ResultType::FETCH_ERROR);
 
   return this->ModelDependencies(_id, _dependencies);
@@ -804,15 +837,10 @@ Result FuelClient::ModelDependencies(
       std::vector<ModelIdentifier> recursiveDeps;
       this->ModelDependencies(modelDeps, recursiveDeps);
 
-      for (auto dep : modelDeps)
-      {
-        newDeps.push_back(dep);
-      }
-
-      for (auto dep : recursiveDeps)
-      {
-        newDeps.push_back(dep);
-      }
+      std::copy(modelDeps.begin(), modelDeps.end(),
+                std::back_inserter(newDeps));
+      std::copy(recursiveDeps.begin(), recursiveDeps.end(),
+                std::back_inserter(newDeps));
     }
   }
 
@@ -839,6 +867,8 @@ Result FuelClient::DownloadWorld(WorldIdentifier &_id,
     return Result(ResultType::FETCH_ERROR);
   }
 
+  this->dataPtr->CheckForDeprecatedUri(_id.Server().Url());
+
   // Route
   common::URIPath route;
   route = route / _id.Owner() / "worlds" / _id.Name() / _id.VersionStr() /
@@ -854,7 +884,7 @@ Result FuelClient::DownloadWorld(WorldIdentifier &_id,
   Rest rest;
   RestResponse resp;
   resp = rest.Request(HttpMethod::GET, _id.Server().Url().Str(),
-      _id.Server().Version(), route.Str(), {},
+      _id.Server().Version(), route.Str(), {"link=true"},
       headersIncludingServerConfig, "");
   if (resp.statusCode != 200)
   {
@@ -888,9 +918,12 @@ Result FuelClient::DownloadWorld(WorldIdentifier &_id,
   }
   _id.SetVersion(version);
 
+  std::string zipData;
+  this->dataPtr->ZipFromResponse(resp, zipData);
+
   // Save
-  if (!this->dataPtr->cache->SaveWorld(_id, resp.data, true))
-    return Result(ResultType::FETCH_ERROR);
+  if (zipData.empty() || !this->dataPtr->cache->SaveWorld(_id, zipData, true))
+      return Result(ResultType::FETCH_ERROR);
 
   return Result(ResultType::FETCH);
 }
@@ -1104,8 +1137,8 @@ bool FuelClient::ParseModelUrl(const common::URI &_modelUrl,
   _id.Server().SetVersion(apiVersion);
   for (const auto &s : this->dataPtr->config.Servers())
   {
-    if (s.Url().Str() == _id.Server().Url().Str())
-    {
+    // cppcheck-suppress useStlAlgorithm
+    if (s.Url().Str() == _id.Server().Url().Str()) {
       if (!apiVersion.empty() && s.Version() != _id.Server().Version())
       {
         ignwarn << "Requested server API version [" << apiVersion
@@ -1170,8 +1203,8 @@ bool FuelClient::ParseWorldUrl(const common::URI &_worldUrl,
   _id.Server().SetVersion(apiVersion);
   for (const auto &s : this->dataPtr->config.Servers())
   {
-    if (s.Url() == _id.Server().Url())
-    {
+    // cppcheck-suppress useStlAlgorithm
+    if (s.Url() == _id.Server().Url()) {
       if (!apiVersion.empty() && s.Version() != _id.Server().Version())
       {
         ignwarn << "Requested server API version [" << apiVersion
@@ -1204,6 +1237,8 @@ bool FuelClient::ParseModelFileUrl(const common::URI &_fileUrl,
   if (!_fileUrl.Valid())
     return false;
 
+  this->dataPtr->CheckForDeprecatedUri(_fileUrl);
+
   auto urlStr = _fileUrl.Str();
 
   std::smatch match;
@@ -1238,8 +1273,8 @@ bool FuelClient::ParseModelFileUrl(const common::URI &_fileUrl,
   _id.Server().SetVersion(apiVersion);
   for (const auto &s : this->dataPtr->config.Servers())
   {
-    if (s.Url().Str() == _id.Server().Url().Str())
-    {
+    // cppcheck-suppress useStlAlgorithm
+    if (s.Url().Str() == _id.Server().Url().Str()) {
       if (!apiVersion.empty() && s.Version() != _id.Server().Version())
       {
         ignwarn << "Requested server API version [" << apiVersion
@@ -1307,8 +1342,8 @@ bool FuelClient::ParseWorldFileUrl(const common::URI &_fileUrl,
   _id.Server().SetVersion(apiVersion);
   for (const auto &s : this->dataPtr->config.Servers())
   {
-    if (s.Url() == _id.Server().Url())
-    {
+    // cppcheck-suppress useStlAlgorithm
+    if (s.Url() == _id.Server().Url()) {
       if (!apiVersion.empty() && s.Version() != _id.Server().Version())
       {
         ignwarn << "Requested server API version [" << apiVersion
@@ -1374,8 +1409,8 @@ bool FuelClient::ParseCollectionUrl(const common::URI &_url,
   _id.Server().SetVersion(apiVersion);
   for (const auto &s : this->dataPtr->config.Servers())
   {
-    if (s.Url() == _id.Server().Url())
-    {
+    // cppcheck-suppress useStlAlgorithm
+    if (s.Url() == _id.Server().Url()) {
       if (!apiVersion.empty() && s.Version() != _id.Server().Version())
       {
         ignwarn << "Requested server API version [" << apiVersion
@@ -1931,3 +1966,79 @@ bool FuelClient::UpdateWorlds(const std::vector<std::string> &_headers)
   }
   return true;
 }
+//////////////////////////////////////////////////
+void FuelClientPrivate::CheckForDeprecatedUri(const common::URI &_uri)
+{
+  static std::string oldServer = "fuel.ignitionrobotics.org";
+  auto ignFuelPos = _uri.Str().find(oldServer);
+  if (ignFuelPos != std::string::npos)
+  {
+    std::string newUrl = _uri.Str();
+    newUrl.replace(ignFuelPos, oldServer.size(), "fuel.gazebosim.org");
+    ignwarn << "The " << oldServer << " URL is deprecrated. Pleasse change "
+      << _uri.Str() << " to " << newUrl << std::endl;
+  }
+}
+
+//////////////////////////////////////////////////
+void FuelClientPrivate::ZipFromResponse(const RestResponse &_resp,
+    std::string &_zip)
+{
+  // Check the content-type which could be empty (ideally not):
+  //   * text/plain indicates the data is a download link.
+  //   * application/zip indicates the data is a zip file.
+  //   * binary/octet-stream indicates the data is a zip file.
+  auto contentTypeIter = _resp.headers.find("Content-Type");
+  if (contentTypeIter != _resp.headers.end())
+  {
+    // If text/plain then data might be a link to a zip file.
+    if (contentTypeIter->second.find("text/plain") != std::string::npos)
+    {
+      std::string linkUri = _resp.data;
+
+      // Check for valid URI
+      if (common::URI::Valid(linkUri))
+      {
+        igndbg << "Downloading from a referral link [" << linkUri << "]\n";
+        // Get the zip data.
+        RestResponse linkResp = rest.Request(HttpMethod::GET,
+            // URL
+            linkUri,
+            // Version
+            "",
+            // Path
+            "",
+            // Query strings
+            {},
+            // Headers
+            {},
+            // Data
+            "");
+
+        return this->ZipFromResponse(linkResp, _zip);
+      }
+      else
+      {
+        ignerr << "Invalid referral link URI [" << linkUri << "]. "
+          << "Unable to download.\n";
+      }
+    }
+    else if (contentTypeIter->second.find("application/zip") !=
+             std::string::npos ||
+             contentTypeIter->second.find("binary/octet-stream") !=
+             std::string::npos)
+    {
+      _zip = std::move(_resp.data);
+    }
+    else
+    {
+      ignerr << "Invalid content-type of [" << contentTypeIter->second << "]. "
+        << "Unable to download.\n";
+    }
+  }
+  else
+  {
+    // If content-type is missing, then assume the data is the zip file.
+    _zip = std::move(_resp.data);
+  }
+}
