@@ -28,16 +28,16 @@
 #include <regex>
 #include <string>
 #include <vector>
-#include <ignition/common/Console.hh>
-#include <ignition/common/Filesystem.hh>
-#include <ignition/common/StringUtils.hh>
-#include <ignition/common/Util.hh>
-#include <ignition/math/SemanticVersion.hh>
+#include <gz/common/Console.hh>
+#include <gz/common/Filesystem.hh>
+#include <gz/common/StringUtils.hh>
+#include <gz/common/Util.hh>
+#include <gz/math/SemanticVersion.hh>
 
-#include "ignition/fuel_tools/ClientConfig.hh"
-#include "ignition/fuel_tools/Helpers.hh"
-#include "ignition/fuel_tools/LocalCache.hh"
-#include "ignition/fuel_tools/Zip.hh"
+#include "gz/fuel_tools/ClientConfig.hh"
+#include "gz/fuel_tools/Helpers.hh"
+#include "gz/fuel_tools/LocalCache.hh"
+#include "gz/fuel_tools/Zip.hh"
 
 #include "ModelPrivate.hh"
 #include "ModelIterPrivate.hh"
@@ -46,7 +46,7 @@
 using namespace ignition;
 using namespace fuel_tools;
 
-class ignition::fuel_tools::LocalCachePrivate
+class gz::fuel_tools::LocalCachePrivate
 {
   /// \brief return all models in a given directory
   /// \param[in] _path A directory for the local server cache
