@@ -51,11 +51,6 @@ class CmdLine : public ::testing::Test
     // instead of on teardown leaves the folder intact for debugging if needed
     common::removeAll(testCachePath);
     ASSERT_TRUE(common::createDirectories(testCachePath));
-    ASSERT_TRUE(common::createDirectories(
-        common::joinPaths(testCachePath, "fuel.gazebosim.org")));
-    ASSERT_TRUE(common::createDirectories(
-        common::joinPaths(testCachePath, "fuel.ignitionrobotics.org")));
-
     setenv("IGN_FUEL_CACHE_PATH", this->testCachePath.c_str(), true);
   }
 
@@ -90,7 +85,7 @@ TEST_F(CmdLine, ModelListFail)
 
   EXPECT_NE(this->stdOutBuffer.str().find("Invalid URL"),
       std::string::npos) << this->stdOutBuffer.str();
-  EXPECT_TRUE(this->stdErrBuffer.str().empty()) << this->stdErrBuffer.str();
+  EXPECT_TRUE(this->stdErrBuffer.str().empty());
 }
 
 /////////////////////////////////////////////////
@@ -352,7 +347,7 @@ TEST_F(CmdLine, WorldDownloadUnversioned)
 {
   // Download
   EXPECT_TRUE(downloadUrl(
-      "https://fuel.gazebosim.org/1.0/OpenRobotics/worlds/Test world"));
+      "https://fuel.gazebosim.org/1.0/openrobotics/worlds/Test world"));
 
   // Check output
   EXPECT_NE(this->stdOutBuffer.str().find("Download succeeded"),
@@ -368,15 +363,17 @@ TEST_F(CmdLine, WorldDownloadUnversioned)
       "openrobotics", "worlds", "test world", "2")));
   EXPECT_TRUE(common::isFile(
     common::joinPaths(this->testCachePath, "fuel.gazebosim.org",
-      "openrobotics", "worlds", "test world", "2", "test.world")));
+      "openrobotics", "worlds", "test world", "2", "test.sdf")));
 }
 
+
 class DownloadCollectionTest
     : public CmdLine,
       public ::testing::WithParamInterface<int>
 {};
 
 INSTANTIATE_TEST_CASE_P(CollectionTest, DownloadCollectionTest,
+                        // cppcheck-suppress syntaxError
                         ::testing::Values(1, 2, 16),); // NOLINT
 
 /////////////////////////////////////////////////
@@ -384,11 +381,11 @@ INSTANTIATE_TEST_CASE_P(CollectionTest, DownloadCollectionTest,
 // https://github.com/gazebosim/gz-fuel-tools/issues/105
 TEST_P(DownloadCollectionTest, AllItems)
 {
+  std::string url =
+   "https://fuel.gazebosim.org/1.0/openroboticstest/collections/testcollection";
+
   // Download
-  EXPECT_TRUE(
-      downloadUrl("https://fuel.gazebosim.org/1.0/OpenRobotics/"
-                  "collections/TestCollection",
-                  nullptr, nullptr, nullptr, GetParam()));
+  EXPECT_TRUE(downloadUrl(url.c_str(), nullptr, nullptr, nullptr, GetParam()));
 
   // Check output
   EXPECT_NE(this->stdOutBuffer.str().find("Download succeeded"),
@@ -399,46 +396,46 @@ TEST_P(DownloadCollectionTest, AllItems)
   // Model: Backpack
   EXPECT_TRUE(common::isDirectory(
     common::joinPaths(this->testCachePath, "fuel.gazebosim.org",
-      "openrobotics", "models", "backpack")));
+      "openroboticstest", "models", "backpack")));
   EXPECT_TRUE(common::isDirectory(
     common::joinPaths(this->testCachePath, "fuel.gazebosim.org",
-      "openrobotics", "models", "backpack", "3")));
+      "openroboticstest", "models", "backpack", "3")));
   EXPECT_TRUE(common::isFile(
     common::joinPaths(this->testCachePath, "fuel.gazebosim.org",
-      "openrobotics", "models", "backpack", "3", "model.sdf")));
+      "openroboticstest", "models", "backpack", "3", "model.sdf")));
 
   // Model: TEAMBASE
   EXPECT_TRUE(common::isDirectory(
     common::joinPaths(this->testCachePath, "fuel.gazebosim.org",
-      "openrobotics", "models", "teambase")));
+      "openroboticstest", "models", "teambase")));
   EXPECT_TRUE(common::isDirectory(
     common::joinPaths(this->testCachePath, "fuel.gazebosim.org",
-      "openrobotics", "models", "teambase", "3")));
+      "openroboticstest", "models", "teambase", "2")));
   EXPECT_TRUE(common::isFile(
     common::joinPaths(this->testCachePath, "fuel.gazebosim.org",
-     "openrobotics", "models", "teambase", "3", "model.sdf")));
+     "openroboticstest", "models", "teambase", "2", "model.sdf")));
 
   // World: Test World
   EXPECT_TRUE(common::isDirectory(
     common::joinPaths(this->testCachePath, "fuel.gazebosim.org",
-      "openrobotics", "worlds", "test world")));
+      "openroboticstest", "worlds", "test world")));
   EXPECT_TRUE(common::isDirectory(
     common::joinPaths(this->testCachePath, "fuel.gazebosim.org",
-      "openrobotics", "worlds", "test world", "2")));
+      "openroboticstest", "worlds", "test world", "2")));
   EXPECT_TRUE(common::isFile(
     common::joinPaths(this->testCachePath, "fuel.gazebosim.org",
-      "openrobotics", "worlds", "test world", "2", "test.world")));
+      "openroboticstest", "worlds", "test world", "2", "test.sdf")));
 
   // World: Test World 2
   EXPECT_TRUE(common::isDirectory(
     common::joinPaths(this->testCachePath, "fuel.gazebosim.org",
-      "openrobotics", "worlds", "test world 2")));
+      "openroboticstest", "worlds", "test world2")));
   EXPECT_TRUE(common::isDirectory(
     common::joinPaths(this->testCachePath, "fuel.gazebosim.org",
-      "openrobotics", "worlds", "test world 2", "2")));
+      "openroboticstest", "worlds", "test world2", "1")));
   EXPECT_TRUE(common::isFile(
     common::joinPaths(this->testCachePath, "fuel.gazebosim.org",
-      "openrobotics", "worlds", "test world 2", "2", "test.world")));
+      "openroboticstest", "worlds", "test world2", "1", "test.sdf")));
 }
 
 /////////////////////////////////////////////////
@@ -449,8 +446,8 @@ TEST_P(DownloadCollectionTest, Models)
 {
   // Download
   EXPECT_TRUE(
-      downloadUrl("https://fuel.gazebosim.org/1.0/OpenRobotics/"
-                  "collections/TestCollection",
+      downloadUrl("https://fuel.gazebosim.org/1.0/openroboticstest/"
+                  "collections/testcollection",
                   nullptr, nullptr, "model", GetParam()));
 
   // Check output
@@ -462,34 +459,34 @@ TEST_P(DownloadCollectionTest, Models)
   // Model: Backpack
   EXPECT_TRUE(common::isDirectory(
     common::joinPaths(this->testCachePath, "fuel.gazebosim.org",
-      "openrobotics", "models", "backpack")));
+      "openroboticstest", "models", "backpack")));
   EXPECT_TRUE(common::isDirectory(
     common::joinPaths(this->testCachePath, "fuel.gazebosim.org",
-      "openrobotics", "models", "backpack", "3")));
+      "openroboticstest", "models", "backpack", "3")));
   EXPECT_TRUE(common::isFile(
     common::joinPaths(this->testCachePath, "fuel.gazebosim.org",
-      "openrobotics", "models", "backpack", "3", "model.sdf")));
+      "openroboticstest", "models", "backpack", "3", "model.sdf")));
 
   // Model: TEAMBASE
   EXPECT_TRUE(common::isDirectory(
     common::joinPaths(this->testCachePath, "fuel.gazebosim.org",
-      "openrobotics", "models", "teambase")));
+      "openroboticstest", "models", "teambase")));
   EXPECT_TRUE(common::isDirectory(
     common::joinPaths(this->testCachePath, "fuel.gazebosim.org",
-      "openrobotics", "models", "teambase", "3")));
+      "openroboticstest", "models", "teambase", "2")));
   EXPECT_TRUE(common::isFile(
     common::joinPaths(this->testCachePath, "fuel.gazebosim.org",
-      "openrobotics", "models", "teambase", "3", "model.sdf")));
+      "openroboticstest", "models", "teambase", "2", "model.sdf")));
 
   // World: Test World
   EXPECT_FALSE(common::isDirectory(
     common::joinPaths(this->testCachePath, "fuel.gazebosim.org",
-      "openrobotics", "worlds", "test world")));
+      "openroboticstest", "worlds", "test world")));
 
   // World: Test World 2
   EXPECT_FALSE(common::isDirectory(
     common::joinPaths(this->testCachePath, "fuel.gazebosim.org",
-      "openrobotics", "worlds", "test world2")));
+      "openroboticstest", "worlds", "test world2")));
 }
 
 /////////////////////////////////////////////////
@@ -500,8 +497,8 @@ TEST_P(DownloadCollectionTest, Worlds)
 {
   // Download
   EXPECT_TRUE(
-      downloadUrl("https://fuel.gazebosim.org/1.0/OpenRobotics/"
-                  "collections/TestCollection",
+      downloadUrl("https://fuel.gazebosim.org/1.0/openroboticstest/"
+                  "collections/testcollection",
                   nullptr, nullptr, "world", GetParam()));
 
   // Check output
@@ -513,32 +510,32 @@ TEST_P(DownloadCollectionTest, Worlds)
   // Model: Backpack
   EXPECT_FALSE(common::isDirectory(
     common::joinPaths(this->testCachePath, "fuel.gazebosim.org",
-      "openrobotics", "models", "backpack")));
+      "openroboticstest", "models", "backpack")));
 
   // Model: TEAMBASE
   EXPECT_FALSE(common::isDirectory(
     common::joinPaths(this->testCachePath, "fuel.gazebosim.org",
-      "openrobotics", "models", "teambase")));
+      "openroboticstest", "models", "teambase")));
 
   // World: Test World
   EXPECT_TRUE(common::isDirectory(
     common::joinPaths(this->testCachePath, "fuel.gazebosim.org",
-      "openrobotics", "worlds", "test world")));
+      "openroboticstest", "worlds", "test world")));
   EXPECT_TRUE(common::isDirectory(
     common::joinPaths(this->testCachePath, "fuel.gazebosim.org",
-      "openrobotics", "worlds", "test world", "2")));
+      "openroboticstest", "worlds", "test world", "2")));
   EXPECT_TRUE(common::isFile(
     common::joinPaths(this->testCachePath, "fuel.gazebosim.org",
-      "openrobotics", "worlds", "test world", "2", "test.world")));
+      "openroboticstest", "worlds", "test world", "2", "test.sdf")));
 
   // World: Test World 2
   EXPECT_TRUE(common::isDirectory(
     common::joinPaths(this->testCachePath, "fuel.gazebosim.org",
-      "openrobotics", "worlds", "test world 2")));
+      "openroboticstest", "worlds", "test world2")));
   EXPECT_TRUE(common::isDirectory(
     common::joinPaths(this->testCachePath, "fuel.gazebosim.org",
-      "openrobotics", "worlds", "test world 2", "2")));
+      "openroboticstest", "worlds", "test world2", "1")));
   EXPECT_TRUE(common::isFile(
     common::joinPaths(this->testCachePath, "fuel.gazebosim.org",
-      "openrobotics", "worlds", "test world 2", "2", "test.world")));
+      "openroboticstest", "worlds", "test world2", "1", "test.sdf")));
 }
